@@ -7,11 +7,11 @@
 #include <Rmath.h>
 #include <Rdefines.h>
 
-typedef void euler_step(double *x, const double *p, 
-			const int *stateindex, const int *parindex,
-			int ncovar, const double *covar,
-			double t, double dt);
-// Description of Euler step functions (type euler_step)
+typedef void euler_step_sim(double *x, const double *p, 
+			    const int *stateindex, const int *parindex,
+			    int ncovar, const double *covar,
+			    double t, double dt);
+// Description of Euler step functions (type euler_step_sim)
 //  on input:
 // x          = pointer to state vector
 // p          = pointer to parameter vector
@@ -27,7 +27,13 @@ typedef void euler_step(double *x, const double *p,
 //  on output:
 // x          = contains the new state vector (i.e., at time t+dt)
 
+typedef void euler_step_pdf(double *f, 
+			    double *x1, double *x2, const double *p, 
+			    const int *stateindex, const int *parindex,
+			    int ncovar, const double *covar,
+			    double t, double dt);
+
 void reulermultinom (int ntrans, double size, double *rate, double dt, double *trans);
-void deulermultinom (int ntrans, double size, double *rate, double *trans, double dt, int give_log, double *f);
+double deulermultinom (int ntrans, double size, double *rate, double dt, double *trans, int give_log);
 
 #endif
